# Cerebro Toolkit Package
This package provide a systematic process of building and improving software codebase without creating new functionality
that can transform a mess into clean code and simple design architect.
<br><br>
This is a core package of [Cerebro](https://github.com/hieupth/cerebro) because we build everything with engineering mindset which means clean code and good 
software architect is our top concern.
<br><br>
We focus on the package in Python because it is our first programming language but we are working hard to make 
cross-platform support as soon as possible.
## Installation
The package can be installed by pip command:
```
pip install cerebro-toolkit
```
## Maintainers
* [Hieu Pham](https://github.com/hieupth) (author)
## License
[MIT License](https://github.com/hieupth/cerebro-toolkit/blob/main/LICENSE). <br>
Copyright &copy; 2021 [Hieu Pham](https://github.com/hieupth). All rights reserved.
<br><br>
*This project was initialized as a part of [Cerebro](https://github.com/hieupth/cerebro) open source project which helps 
to build  intelligence system that run everywhere for everyone.*
